alphaStar: compute mean adjusted adherence, the recommended figure of...

View source: R/alphaStar.R

alphaStarR Documentation

compute mean adjusted adherence, the recommended figure of merit for bayesCC

Description

compute mean adjusted adherence, the recommended figure of merit for bayesCC

Usage

alphaStar(Results)

Arguments

Results

a list (the output from one completed run of bayesCC(...))

Value

a vector of mean-adjusted adherences for the run, a.k.a. alphaStar

Examples


# see ?bayesCC
data(Results)
alphaStarDist <- data.frame(lapply(Results, alphaStar))
boxplot(alphaStarDist, main="Mean-adjusted adherence by number of clusters")

# add a violin plot
library(vioplot)
cols <- c("tomato","springgreen","darkorange","yellow")
for(i in seq_along(alphaStarDist)) {
  vioplot(alphaStarDist[[i]], col=cols[i], at=i, add=TRUE)   
}


ttriche/bayesCC documentation built on May 13, 2023, 11:48 a.m.