jointNMF: attempt a joint nonnegative matrix factorization of two...

View source: R/jointNMF.R

jointNMFR Documentation

attempt a joint nonnegative matrix factorization of two matrices, as described in Wang et al. 2014, doi:10.1093/bioinformatics/btu679

Description

attempt a joint nonnegative matrix factorization of two matrices, as described in Wang et al. 2014, doi:10.1093/bioinformatics/btu679

Usage

jointNMF(
  mat1,
  mat2,
  findK = FALSE,
  howNA = c("both", "column", "row"),
  viaCV = FALSE,
  fracNA = 0.2
)

Arguments

mat1

the first matrix

mat2

the second matrix

findK

try to find the rank K for each matrix?

howNA

for rank finding, add NAs column-wise, row-wise, or both?

viaCV

for rank finding, should five-fold CV be used when imputing?

fracNA

for rank finding, what fraction of the data should be NA'ed?


ttriche/bayesCC documentation built on May 13, 2023, 11:48 a.m.