| jointNMF | R Documentation |
attempt a joint nonnegative matrix factorization of two matrices, as described in Wang et al. 2014, doi:10.1093/bioinformatics/btu679
jointNMF(
mat1,
mat2,
findK = FALSE,
howNA = c("both", "column", "row"),
viaCV = FALSE,
fracNA = 0.2
)
mat1 |
the first matrix |
mat2 |
the second matrix |
findK |
try to find the rank K for each matrix? |
howNA |
for rank finding, add NAs column-wise, row-wise, or both? |
viaCV |
for rank finding, should five-fold CV be used when imputing? |
fracNA |
for rank finding, what fraction of the data should be NA'ed? |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.